<?php

namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Factories\StoreRepository;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;

class StoreManagement extends CrudWithParameterBag {

    protected $dataSourceName = 'cadastroloja';
    protected $dataSourceNameToSave = 'saveloja';
    protected $dataSourceNameFindFilial = 'findfilial';
    protected $dataSourceNameToEdit = 'editloja';
    protected $parameterBagColumns = array('NRORG');
    protected $storeRepository;


	public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, StoreRepository $storeRepository) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->storeRepository = $storeRepository;
    }

    public function save(Request\DataSet $request, Response $response) {
        try {
            $dataSet = $request->getDataSet();
            if ($dataSet->getRows()[0]['__is_new']){
                $dataSet->setDataSourceName($this->dataSourceNameToSave);
            }
            else {
                $dataSet->setDataSourceName($this->dataSourceNameToEdit);
            }
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
            if($request->getDataSet()->getRows()[0]['IDATIVO'] == 'N'){
                $response->addNotification(new Notification("Excluído com sucesso!", Notification::TYPE_SUCCESS));
            } else {
                $response->addNotification(new Notification("Salvo com sucesso!", Notification::TYPE_SUCCESS));
            }
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findFilial(Request\Filter $request, Response $response){
        $this->dataSourceName = $this->dataSourceNameFindFilial;
        parent::find($request, $response);
    }

    public function validationStore(Request\DataSet $request, Response $response){
        $rows = $request->getDataSet()->getRows();
        foreach ($rows as $row) {
            $return = $this->storeRepository->validationStore($row['CDFILIAL'], $row['CDLOJA'], $row['NRORG']);
            $response->addDataSet(new DataSet("validationStore", $return));
        }
    }
}